Sampen
--------------------


.. image:: https://img.shields.io/pypi/v/sampen.svg
   :target: https://pypi.org/project/sampen/
.. image:: https://img.shields.io/pypi/pyversions/sampen.svg
  :target: https://pypi.org/project/sampen/

Partial port of v1.2 C-language code for estimating Sample Entropy using SampEn from PhysioNet to Python.

C-language code last updated 1 November 2004, by George Moody.

Original author Doug Lake. dlake@virginia.edu

Functions ported:

- ``normalize_data()``

- ``sampen2()``

Not ported:

- ``readdata()``

- ``sampen()``

For more information and the repository please checkout:

- original C-language code and docs: http://www.physionet.org/physiotools/sampen/

- home and docs: http://sampen.readthedocs.io/en/stable/

- repository: https://github.com/Kinsa/sampen/
